Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(193)

Unified Diff: third_party/WebKit/Source/core/dom/Element.h

Issue 1858163002: Rename inDocument() to inShadowIncludingDocument() (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/core/dom/Document.cpp ('k') | third_party/WebKit/Source/core/dom/Element.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/core/dom/Element.h
diff --git a/third_party/WebKit/Source/core/dom/Element.h b/third_party/WebKit/Source/core/dom/Element.h
index 6203c0a5314d206979f6d5dacb89a620eb241c23..e72889687bb6ae82b3d65ad5c5b2e6b9a16e9d0a 100644
--- a/third_party/WebKit/Source/core/dom/Element.h
+++ b/third_party/WebKit/Source/core/dom/Element.h
@@ -551,7 +551,7 @@ public:
uint32_t compositorMutableProperties() const;
// Helpers for V8DOMActivityLogger::logEvent. They call logEvent only if
// the element is inDocument() and the context is an isolated world.
void logAddElementIfIsolatedWorldAndInDocument(const char element[], const QualifiedName& attr1);
void logAddElementIfIsolatedWorldAndInDocument(const char element[], const QualifiedName& attr1, const QualifiedName& attr2);
void logAddElementIfIsolatedWorldAndInDocument(const char element[], const QualifiedName& attr1, const QualifiedName& attr2, const QualifiedName& attr3);
@@ -849,8 +849,8 @@ inline Node::InsertionNotificationRequest Node::insertedInto(ContainerNode* inse
{
ASSERT(!childNeedsStyleInvalidation());
ASSERT(!needsStyleInvalidation());
- ASSERT(insertionPoint->inDocument() || insertionPoint->isInShadowTree() || isContainerNode());
- if (insertionPoint->inDocument()) {
+ ASSERT(insertionPoint->inShadowIncludingDocument() || insertionPoint->isInShadowTree() || isContainerNode());
+ if (insertionPoint->inShadowIncludingDocument()) {
setFlag(InDocumentFlag);
insertionPoint->document().incrementNodeCount();
}
@@ -863,8 +863,8 @@ inline Node::InsertionNotificationRequest Node::insertedInto(ContainerNode* inse
inline void Node::removedFrom(ContainerNode* insertionPoint)
{
- ASSERT(insertionPoint->inDocument() || isContainerNode() || isInShadowTree());
- if (insertionPoint->inDocument()) {
+ ASSERT(insertionPoint->inShadowIncludingDocument() || isContainerNode() || isInShadowTree());
+ if (insertionPoint->inShadowIncludingDocument()) {
clearFlag(InDocumentFlag);
insertionPoint->document().decrementNodeCount();
}
@@ -551,7 +551,7 @@ public:
uint32_t compositorMutableProperties() const;
// Helpers for V8DOMActivityLogger::logEvent. They call logEvent only if
- // the element is inDocument() and the context is an isolated world.
+ // the element is inShadowIncludingDocument() and the context is an isolated world.
void logAddElementIfIsolatedWorldAndInDocument(const char element[], const QualifiedName& attr1);
void logAddElementIfIsolatedWorldAndInDocument(const char element[], const QualifiedName& attr1, const QualifiedName& attr2);
« no previous file with comments | « third_party/WebKit/Source/core/dom/Document.cpp ('k') | third_party/WebKit/Source/core/dom/Element.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698